<?php

namespace Eye4fraud\API;

use Eye4fraud\Log\Log;

class Eye4fraud {

	private $ApiLogin;
	private $ApiKey;
	private $ApiUrl;

	/**
	 *
	 * Constructor
	 *
	 * @param $ApiLogin
	 * @param $ApiKey
	 * @param string $ApiUrl
	 *
	 */
	public function __construct( $ApiLogin, $ApiKey, $ApiUrl = '' ) {
		$this->ApiLogin = $ApiLogin;
		$this->ApiKey = $ApiKey;
		$this->ApiUrl = $ApiUrl;
	}


	/**
	 *
	 * Wp_remote_post send to eye4fraud API.
	 *
	 * @param string $send_order
	 * @return array
	 *
	 */
	public function send_eye4fraud_api( $send_order = '' ) {
		$status = array(
			'success' => false
		);

		if ( $send_order && is_array( $send_order ) ) {
			$response = wp_remote_post( $this->ApiUrl, array(
					'method' => 'POST',
					'timeout' => 45,
					'httpversion' => '1.0',
					'blocking' => true,
					'headers' => array(),
					'body' => $send_order,
					'cookies' => array()
				)
			);

			$api_response = wp_remote_retrieve_body( $response );
			Log::debug_log_content( 'Got response from eye4fraud:' );
			Log::debug_log_content( '-----------------------------' );
			Log::debug_log_content( $api_response );
			Log::debug_log_content( '-----------------------------' );

			$status['error'] = $api_response;

			if ( is_wp_error( $response ) ) {
				$error_message = $response->get_error_message();
				$status['error'] = $error_message;
			} else {
				if ( 'ok' == $api_response ) {
					$status['error'] = '';
					$status['success'] = true;
				}
			}
		}

		return $status;
	}


	/**
	 *
	 * Get Eye4fraud Order Status
	 *
	 * @param $order_id
	 * @param string $post_array
	 * @return array
	 *
	 */
	public function get_eye4fraud_status_api( $order_id ) {
		$status = array(
			'success' => false
		);

		$post_array = array(
			'ApiLogin' => $this->ApiLogin,
			'ApiKey' => $this->ApiKey,
			'Action' => 'getOrderStatus',
			'OrderNumber' => $order_id
		);

		if ( !empty( $order_id ) ) {
			$response = wp_remote_post( $this->ApiUrl, array(
					'method' => 'POST',
					'timeout' => 45,
					'httpversion' => '1.0',
					'blocking' => true,
					'headers' => array(),
					'body' => $post_array,
					'cookies' => array()
				)
			);

			$api_response = wp_remote_retrieve_body( $response );
			Log::debug_log_content( 'Got response from eye4fraud for order id ' . $order_id );
			Log::debug_log_content( '-----------------------------' );
			Log::debug_log_content( $api_response );
			Log::debug_log_content( '-----------------------------' );

			if ( is_wp_error( $response ) ) {
				$error_message = $response->get_error_message();
				$status['error'] = $error_message;
			} else {
				$convert_xml = simplexml_load_string( $api_response );
				foreach ( $convert_xml as $keyValue ) {
					if ( 'Description' == $keyValue->key ) {
						$desc = $keyValue->value;
						$status['description'] = $desc;
						$status['success'] = true;
					}
				}
			}
		}
		return $status;
	}
}
