<?php

namespace Eye4fraud\Admin;

use Eye4fraud\Base\BaseController;

use Eye4fraud\Admin\Column;

use Eye4fraud\Base\Enqueue;

class Admin extends BaseController {

	/**
	 * Register function which will act as constructor
	 */
	public function register() {
		add_filter( 'woocommerce_settings_tabs_array', array( $this, 'add_settings_tab' ), 50 );
		add_action( 'woocommerce_settings_tabs_' . $this->domain, array( $this, 'settings_tab' ) );
		add_action( 'woocommerce_update_options_' . $this->domain, array( $this, 'update_settings' ) );
		add_action( 'admin_init', array( $this, 'redirect_page' ) );

		$admin_page = new Page();
		$admin_column = new Column();
		$admin_column->register();
		$admin_page->register();
	}


	/**
	 * Redirect Page on Plugin activation admin_init
	 */
	public function redirect_page() {
		if ( get_option( 'redirect_page', false ) ) {
			delete_option( 'redirect_page' );
			$site_url = site_url();
			wp_redirect( $site_url . '/wp-admin/admin.php?page=e4f-setting-admin' );
			exit();
		}
	}


	/**
	 * Add Settings Tab
	 *
	 * @param $settings_tabs
	 * @return
	 */
	public function add_settings_tab( $settings_tabs ) {
		$settings_tabs[$this->domain] = __( 'Eye4fraud', 'woocommerce-settings-tab-demo' );
		return $settings_tabs;
	}


	/**
	 *
	 * Uses the WooCommerce admin fields API to output settings via the woocommerce_admin_fields() function.
	 *
	 */
	public function settings_tab() {
		woocommerce_admin_fields( $this->get_settings() );
	}


	/**
	 *
	 * Uses the WooCommerce options API to save settings via the woocommerce_update_options() function.
	 *
	 */
	public function update_settings() {
		woocommerce_update_options( $this->get_settings() );
	}


	/**
	 *
	 * Get all the settings for this plugin for woocommerce_admin_fields() function.
	 *
	 * Array of settings for woocommerce_admin_fields() function.
	 *
	 * @return mixed
	 */
	public function get_settings() {
		$settings = array(
			$this->domain . 'settings_section' => array(
				'title' => __( 'Eye4Fraud Settings', 'eye4fraud' ),
				'type' => 'title',
				'desc' => ''
			),

			$this->domain . '_api_enabled' => array(
				'id' => 'wc_settings_' . $this->domain . '_api_enabled',
				'name' => __( 'Enable / Disable', 'eye4fraud' ),
				'type' => 'checkbox',
				'default' => '',
				'css' => 'width:50%'
			),

			$this->domain . '_api_login' => array(
				'id' => 'wc_settings_' . $this->domain . '_api_login',
				'name' => __( 'API Login', 'eye4fraud' ),
				'type' => 'text',
				'default' => '',
				'css' => 'width:50%'
			),

			$this->domain . '_api_key' => array(
				'id' => 'wc_settings_' . $this->domain . '_api_key',
				'name' => __( 'API Key', 'eye4fraud' ),
				'type' => 'text',
				'default' => '',
				'css' => 'width:50%'
			),

			$this->domain . '_api_btn' => array(
				'id' => 'wc_settings_' . $this->domain . '_api_btn',
				'name' => __( 'Send All Order Request To Eye4Fraud', 'eye4fraud' ),
				'type' => 'btn',
				'default' => '',
				'css' => 'width:50%'
			),

			$this->domain . '_order_limit_day' => array(
				'id' => 'wc_settings_' . $this->domain . '_order_limit_day',
				'name' => __( 'Order update limit (day)', 'eye4fraud' ),
				'type' => 'select',
				'default' => '1',
				'css' => 'width:50%',
				'options' => array(
					'1' => __( '1', 'eye4fraud' ),
					'2' => __( '2', 'eye4fraud' ),
					'3' => __( '3', 'eye4fraud' ),
					'4' => __( '4', 'eye4fraud' ),
					'5' => __( '5', 'eye4fraud' ),
					'6' => __( '6', 'eye4fraud' ),
					'7' => __( '7', 'eye4fraud' ),
					'8' => __( '8', 'eye4fraud' ),
					'9' => __( '9', 'eye4fraud' ),
					'10' => __( '10', 'eye4fraud' ),
					'11' => __( '11', 'eye4fraud' ),
					'12' => __( '12', 'eye4fraud' ),
					'13' => __( '13', 'eye4fraud' ),
					'14' => __( '14', 'eye4fraud' ),
					'15' => __( '15', 'eye4fraud' ),
					'16' => __( '16', 'eye4fraud' ),
					'17' => __( '17', 'eye4fraud' ),
					'18' => __( '18', 'eye4fraud' ),
					'19' => __( '19', 'eye4fraud' ),
					'20' => __( '20', 'eye4fraud' ),
					'21' => __( '21', 'eye4fraud' ),
					'22' => __( '22', 'eye4fraud' ),
					'23' => __( '23', 'eye4fraud' ),
					'24' => __( '24', 'eye4fraud' ),
					'25' => __( '25', 'eye4fraud' ),
					'26' => __( '26', 'eye4fraud' ),
					'27' => __( '27', 'eye4fraud' ),
					'28' => __( '28', 'eye4fraud' ),
					'29' => __( '29', 'eye4fraud' ),
					'30' => __( '30', 'eye4fraud' ),
					'31' => __( '31', 'eye4fraud' ),
					'32' => __( '32', 'eye4fraud' ),
					'33' => __( '33', 'eye4fraud' ),
					'34' => __( '34', 'eye4fraud' ),
					'35' => __( '35', 'eye4fraud' ),
					'36' => __( '36', 'eye4fraud' ),
					'37' => __( '37', 'eye4fraud' ),
					'38' => __( '38', 'eye4fraud' ),
					'39' => __( '39', 'eye4fraud' ),
					'40' => __( '40', 'eye4fraud' ),
					'41' => __( '41', 'eye4fraud' ),
					'42' => __( '42', 'eye4fraud' ),
					'43' => __( '43', 'eye4fraud' ),
					'44' => __( '44', 'eye4fraud' ),
					'45' => __( '45', 'eye4fraud' ),
					'46' => __( '46', 'eye4fraud' ),
					'47' => __( '47', 'eye4fraud' ),
					'48' => __( '48', 'eye4fraud' ),
					'49' => __( '49', 'eye4fraud' ),
					'50' => __( '50', 'eye4fraud' )
				),
				'desc_tip' => true
			),

			$this->domain . '_run_cron_every' => array(
				'id' => 'wc_settings_' . $this->domain . '_run_cron_every',
				'name' => __( 'Run Cron Every', 'eye4fraud' ),
				'type' => 'select',
				'default' => '1',
				'css' => 'width:50%',
				'options' => array(
					'300' => __( 'Every 5 mins', 'eye4fraud' ),
					'600' => __( 'Every 10 mins', 'eye4fraud' ),
					'900' => __( 'Every 15 mins', 'eye4fraud' ),
					'1200' => __( 'Every 20 mins', 'eye4fraud' ),
					'1800' => __( 'Every 30 mins', 'eye4fraud' ),
					'3600' => __( 'Every hour ', 'eye4fraud' ),
					'21600' => __( 'Every 6 hours', 'eye4fraud' ),
					'43200' => __( 'Every Twice in a day', 'eye4fraud' ),
					'86400' => __( 'Every Day', 'eye4fraud' )
				),
				'desc_tip' => true
			),

			$this->domain . '_api_cancel_orders' => array(
				'id' => 'wc_settings_' . $this->domain . '_api_cancel_orders',
				'name' => __( 'Cancel Order If fraud / Declined', 'eye4fraud' ),
				'type' => 'checkbox',
				'desc' => __( 'Cancel Order if Eye4fraud cancelled', 'eye4fraud' ),
				'default' => '',
				'css' => 'width:50%'
			),

//			$this->domain . '_changestatus_orders' => array(
//				'id' => 'wc_settings_' . $this->domain . '_changestatus_orders',
//				'name' => __( 'Change Status', 'eye4fraud' ),
//				'type' => 'checkbox',
//				'desc' => __( 'Change processing status if Eye4Fraud Approved ', 'eye4fraud' ),
//				'default' => '',
//				'css' => 'width:50%'
//			),

			$this->domain . '_changestatus_orders2' => array(
				'id' => 'wc_settings_' . $this->domain . '_changestatus_orders2',
				'name' => __( 'Change Status for Approved / Insured orders', 'eye4fraud' ),
				'type' => 'select',
				'default' => '1',
				'css' => 'width: 50%',
				'options' => array(
					'' => __( 'Do Not Change', 'eye4fraud' ),
					'processing' => __( 'Processing', 'eye4fraud' ),
					'completed' => __( 'Completed', 'eye4fraud' ),
					'on-hold' => __( 'On Hold', 'eye4fraud' ),

				),
				'desc_tip' => true
			),

			$this->domain . '_disable_cron' => array(
				'id' => 'wc_settings_' . $this->domain . '_disable_cron',
				'name' => __( 'Enable / Disable Cron', 'eye4fraud' ),
				'type' => 'checkbox',
				'desc' => 'Check to disable cron',
				'default' => '',
				'css' => 'width:50%'
			),

			$this->domain . '_debug_enabled' => array(
				'id' => 'wc_settings_' . $this->domain . '_debug_enabled',
				'name' => __( 'Enable / Disable Log', 'eye4fraud' ),
				'type' => 'checkbox',
				'desc' => 'Check to enable the log',
				'default' => '',
				'css' => 'width:50%'
			),

			$this->domain . '_settings_section_end' => array(
				'type' => 'sectionend'
			)
		);

		return apply_filters( 'wc_settings_tab_demo_settings', $settings );
	}


	/**
	 * Get Eye4fraud settings
	 *
	 * Initialize array to get eye4fraud settings
	 *
	 */
	public function get_eye4fraud_settings() {
		$api_url = 'https://www.eye4fraud.com/api';

		$settings = array();
		$settings[$this->domain . '_api_enabled'] = get_option( 'wc_settings_' . $this->domain . '_api_enabled' ) == 'yes' ? 1 : 0;
		$settings[$this->domain . '_api_login'] = get_option( 'wc_settings_' . $this->domain . '_api_login' );
		$settings[$this->domain . '_api_key'] = get_option( 'wc_settings_' . $this->domain . '_api_key' );
		$settings[$this->domain . '_api_url'] = $api_url;
		$settings[$this->domain . '_disable_cron'] = get_option( 'wc_settings_' . $this->domain . '_disable_cron' );
		$settings[$this->domain . '_run_cron_every'] = get_option( 'wc_settings_' . $this->domain . '_run_cron_every' );
		$settings[$this->domain . '_order_limit_day'] = get_option( 'wc_settings_' . $this->domain . '_order_limit_day' );
		$settings[$this->domain . '_api_cancel_orders'] = get_option( 'wc_settings_' . $this->domain . '_api_cancel_orders' );
		$settings[$this->domain . '_changestatus_orders2'] = get_option( 'wc_settings_' . $this->domain . '_changestatus_orders2' );

		return $settings;
	}
}
