<?php

namespace Eye4fraud\Admin;

use Eye4fraud\Base\BaseController;
use Eye4fraud\Database\Queries;
use Eye4fraud\Log\Log;
use Eye4fraud\API\Eye4fraud;
use Eye4fraud\Services\SendOrder;


class Column extends BaseController {

	/**
	 * Register function which will act as constructor
	 */
	public function register() {
		add_filter( 'manage_edit-shop_order_columns', array( $this, 'wc_custom_column' ) );
		add_action( 'manage_shop_order_posts_custom_column', array( $this, 'wc_custom_render_column' ), 3 );
		add_action( 'wp_ajax_eye4fraud_ajax_order', array( $this, 'eye4fraud_ajax_order' ) );
		add_action( 'wp_ajax_eye4fraud_ajax_order_resend', array( $this, 'eye4fraud_ajax_order_resend' ) );
		add_action( 'wp_ajax_web_eye4fraud_api', array( $this, 'web_eye4fraud_api' ) );
	}


	/**
	 * Add Eye4fraud Custom Column
	 *
	 * @param $columns
	 * @return array
	 *
	 */
	public function wc_custom_column( $columns ) {
		$columns = array_merge( array_slice( $columns, 0, 5 ), array(
			'eye4fraud_status' => 'Eye4Fraud Status'
		), array_slice( $columns, 5 ) );

		$columns = array_merge( array_slice( $columns, 0, 6 ), array( 'eye4fraud_resendorder' => 'Order Resend' ), array_slice( $columns, 6 ) );
		return $columns;
	}


	/**
	 *
	 * Render Column data
	 *
	 * @param $column
	 *
	 */
	public function wc_custom_render_column( $column ) {
		global $post;
		$post_id = $post->ID;

		if ( 'eye4fraud_status' == $column ) {
			$status = Queries::get_eye4fraud_status( $post_id );

			if ( !empty( $status ) ) {
				$eye4fraud_status = $status->status;
				$this->show_order_status_html( $eye4fraud_status );
				$this->get_order_status_link( $post_id, $eye4fraud_status );
			} else {
				echo '<div style="text-align: center;"><strong>No Order</strong></div>';
			}
		}

		if ( 'eye4fraud_resendorder' == $column ) {
			$status = Queries::get_eye4fraud_status( $post_id );

			if ( empty( $status ) ) {
				echo "<div class='resend_order_status' data-attr='resend-" . esc_html( $post_id ) . "'>";
				echo '<a style="background: red;color: #fff;padding: 8px; border-radius: 5px;" href="javascript:void(0)" class="order_resend_submit" id="' . esc_html( $post_id ) . '">Order Not Submitted</a>';
				echo '</div>';
			} else {
				echo '<mark style="background:green;color:#fff" class="order-status status-processing"><span>Order Submitted</span></mark>';
			}
		}
	}


	/**
	 * Show Order Status HTML
	 *
	 * @param $current_e4f_order_status
	 *
	 */
	public function show_order_status_html( $current_e4f_order_status ) {
		echo '<div style="text-align: center;"><strong style="display: block;">' . esc_html( $current_e4f_order_status ) . '</strong></div>';
	}


	/**
	 * Get Order Status link if matched
	 *
	 * @param $order_id
	 * @param $current_e4f_order_status
	 *
	 */
	public function get_order_status_link( $order_id, $current_e4f_order_status ) {
		$exclude_status = array( 'Declined', 'Canceled', 'Fraud', 'Missed Fraud', 'Error', 'Invalid' );
		if ( !in_array( $current_e4f_order_status, $exclude_status ) ) {
			echo '<div style="text-align: center"><a href="#" class="e4f_submit" id="' . esc_html( $order_id ) . '">Get Order Status</a></div>';
		}
	}


	/**
	 * Get Eye4fraud Status via Ajax from Woocommerce Order Admin
	 */
	public function eye4fraud_ajax_order() {
		$order_id = isset( $_POST['order_id'] ) ? intval( $_POST['order_id'] ) : 0;
		Log::debug_log_content( 'Ajax - Start for order id ' . $order_id );

		if ( $order_id && isset( $_REQUEST['_wpnonce'] ) && sanitize_text_field( wp_unslash( $_REQUEST['_wpnonce'] ) ) ) {
			wp_verify_nonce( sanitize_text_field( wp_unslash( $_REQUEST['_wpnonce'] ) ) );
		}

		$response = array(
			'success' => false,
			'description' => '',
			'order_id' => ''
		);

		if ( $order_id ) {
			$admin = new Admin();
			$settings = $admin->get_eye4fraud_settings();
			$eye4fraud_object = new Eye4fraud(
				$settings['eye4fraud_api_login'],
				$settings['eye4fraud_api_key'],
				$settings['eye4fraud_api_url']
			);
			$orderStatus = $eye4fraud_object->get_eye4fraud_status_api( $order_id );

			if ( $orderStatus['success'] ) {
				$desc = (string) $orderStatus['description'];

				if ( 'yes' == $settings['eye4fraud_api_cancel_orders'] ) {
					if ( 'Canceled' == $desc || 'Declined' == $desc || 'Fraud' == $desc ) {
						$order_cancel = wc_get_order( $order_id );
						$order_cancel->update_status( 'cancelled', 'Order is cancelled as Eye4Fraud has cancelled the order' );
						Log::debug_log_content( 'Order id ' . $order_id . ' canceled.' );
					}
				}

				if ( 'Approved' == $desc || 'Insured' == $desc || 'Unprocessed' == $desc ) {

					$payment_method = get_post_meta( $order_id, '_payment_method', true );
					Log::debug_log_content( 'payment_method = ' . $payment_method );

					$order_new = wc_get_order( $order_id );
					$orderData = $order_new->get_data();
					if ( 'completed' != $orderData['status'] ) {
						$order_new->update_status( 'processing' );
						$order_new->add_order_note( 'Eye4fraud Status: ' . $desc . '  Woocommerce -- Order Status changed to Processing' );
					}
				}

				Queries::update_status_on_cron( $order_id, $desc );
				Log::debug_log_content( 'Order id: ' . $order_id . ' Status Updated: ' . $desc );

				$response['success'] = true;
				$response['order_id'] = $order_id;
				$response['description'] = $desc;
			}
		}

		echo json_encode( $response );
		wp_die();
	}


	/**
	 * Ajax function on order resend
	 */
	public function eye4fraud_ajax_order_resend() {
		$send_order = new SendOrder();

		$order_id = isset( $_POST['order_id'] ) ? intval( $_POST['order_id'] ) : 0;
		Log::debug_log_content( 'Ajax Resend - Start for order id ' . $order_id );

		if ( $order_id && isset( $_REQUEST['_wpnonce'] ) && sanitize_text_field( wp_unslash( $_REQUEST['_wpnonce'] ) ) ) {
			wp_verify_nonce( sanitize_text_field( wp_unslash( $_REQUEST['_wpnonce'] ) ) );
		}

		$response = array(
			'success' => false,
			'description' => '',
			'order_id' => ''
		);

		$status = Queries::get_eye4fraud_status( $order_id );
		if ( empty( $status ) ) {
			$send_order->thankyou_page( $order_id );
			$response['success'] = true;
			$response['order_id'] = $order_id;
		}

		echo json_encode( $response );
		wp_die();
	}





	/**
	 * Web eye4fraud api
	 */
	public function web_eye4fraud_api() {

		$nonce = isset( $_REQUEST['_wpnonce'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['_wpnonce'] ) ) : 1;
		$doSomething = 0;
		if ( !wp_verify_nonce( $nonce, 'my-nonce' ) ) {
			$doSomething++;
		}
		$doSomething++;

		if ( isset( $_POST['register_new'] ) && intval( sanitize_key( $_POST['register_new'] ) ) && $doSomething ) {

			$company_address = isset( $_POST['address-line-1'] ) ? sanitize_key( $_POST['address-line-1'] ) : '';
			$company_city = isset( $_POST['city'] ) ? sanitize_key( $_POST['city'] ) : '';
			$company_legal_name = isset( $_POST['company-name'] ) ? sanitize_key( $_POST['company-name'] ) : '';
			$company_country = isset( $_POST['select-country'] ) ? sanitize_key( $_POST['select-country'] ) : '';
			$username = isset( $_POST['p-email-address'] ) ? sanitize_key( $_POST['p-email-address'] ) : '';
			$email = isset( $_POST['email-address'] ) ? sanitize_email( $_POST['email-address'] ) : '';
			$firstName = isset( $_POST['first-name'] ) ? sanitize_key( $_POST['first-name'] ) : '';
			$last_name = isset( $_POST['last-name'] ) ? sanitize_key( $_POST['last-name'] ) : '';
			$phone = isset( $_POST['p-phone-number'] ) ? sanitize_key( $_POST['p-phone-number'] ) : '';
			$company_website = isset( $_POST['company-website'] ) ? sanitize_key( $_POST['company-website'] ) : '';
			$company_state = isset( $_POST['select-state'] ) ? sanitize_key( $_POST['select-state'] ) : '';
			$company_zip = isset( $_POST['zip-code'] ) ? sanitize_key( $_POST['zip-code'] ) : '';


			$post_array = array(
				'address' => $company_address,
				'city' => $company_city,
				'company_name' => $company_legal_name,
				'country' => $company_country,
				'createdBy' => $username,
				'email' => $email,
				'first_name' => $firstName,
				'last_name' => $last_name,
				'phone' => $phone,
				'site' => $company_website,
				'state' => $company_state,
				'zip' => $company_zip,
			);

			$token = $this->getToken();
//			var_dump($post_array, $token);
			Log::debug_log_content( 'UI - post array : ' . print_r( $post_array, 1 ) . ' ; token : ' . $token );

			if ( !$token ) {
				$res = [
					'success' => false,
					'text' => 'Error! Cannot get token.',
				];
				echo json_encode( $res );
				Log::debug_log_content( 'UI - error - no token!' );
				exit();
			}

			$response = $this->sendE4FRequest( $token, 'https://api.eye4fraud.com/v2/wizards/msu', $post_array );
			Log::debug_log_content( 'UI - response : ' . print_r( $response, 1 ) );

//			var_dump($response);die;
			if ( !$response ) {
				$res = [
					'success' => false,
					'text' => 'Cannot create user. Please ask support.',
				];
				echo json_encode( $res );
				Log::debug_log_content( 'UI - error - Cannot create user!' );
				exit();
			} else if ( 'error' == $response->status ) {
				$res = [
					'success' => false,
					'text' => $response->result,
				];
				Log::debug_log_content( 'UI - error - ' . $response->result );
				echo json_encode( $res );
				exit();
			}


			echo json_encode( array(
				'success' => true,
				'api_key' => $response->result->api_key,
				'api_login' => $response->result->api_login
			) );
			wp_die();
		}
	}



	public function getToken() {
		$response = $this->sendRequest(
			'https://api.eye4fraud.com/v2/login/service',
			array(
				'service_name' => 'woocommerce',
				'service_password' => 'wU88WPuQXhDW4Y2gV6UEjB'
			),
			array()
//			array(
//				'Content-Type: application/json'
//			)
		);
		Log::debug_log_content( 'UI - getToken response : ' . print_r( $response, 1 ) );

//		var_dump($response);
		$token = '';
		if ( $response && 200 == $response->code ) {
			$token = $response->result->token;
		}
		return $token;
	}


	public function sendE4FRequest( $token, $url, $postFields ) {
		if ( $token ) {
			$authkeys = array(
				'Content-Type' => 'application/json',
				'Authorization' => 'Bearer ' . $token
			);

			return $this->sendRequest( $url, $postFields, $authkeys );
		}
		return null;
	}


	public function sendRequest( $url, $postFields, $headFields ) {
		$response = wp_remote_post( $url, array(
				'method' => 'POST',
				'timeout' => 45,
				'httpversion' => '1.0',
				'blocking' => true,
				'headers' => $headFields,
				'body' => json_encode($postFields),
				'cookies' => array()
			)
		);
		$api_response = wp_remote_retrieve_body( $response );
		Log::debug_log_content( 'UI - api_response : ' . print_r( $api_response, 1 ) );

//		var_dump($url, json_encode($postFields), $headFields, $api_response);//die;

		if ( is_wp_error( $response ) ) {
			$error_message = $response->get_error_message();
			Log::debug_log_content( 'UI - error_message : ' . $response );

//			var_dump($error_message);
		} else {
			return json_decode( $api_response );
		}

		return null;

	//	$curl = curl_init();
	//
	//	curl_setopt_array( $curl, array(
	//		CURLOPT_URL => $url,
	//		CURLOPT_RETURNTRANSFER => true,
	//		CURLOPT_ENCODING => '',
	//		CURLOPT_MAXREDIRS => 10,
	//		CURLOPT_TIMEOUT => 0,
	//		CURLOPT_FOLLOWLOCATION => true,
	//		CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
	//		CURLOPT_CUSTOMREQUEST => 'POST',
	//		CURLOPT_POSTFIELDS => $postFields,
	//		CURLOPT_HTTPHEADER => $headFields,
	//	) );
	//
	//	$response = curl_exec( $curl );
	//	curl_close( $curl );
	}



}
