<?php

namespace Eye4fraud\Database;

class Queries {

	const TABLE_EYE4FRAUD = 'eye4fraud_status';


	/**
	 * Insert Eye4fraud status
	 *
	 * @param $data
	 * @return void
	 *
	 */
	public static function insert_eye4fraud_status( $data ) {
		global $wpdb;

		$wpdb->insert(
			$wpdb->prefix . self::TABLE_EYE4FRAUD,
			$data
		);
	}


	/**
	 * Get Eye4fraud Status
	 *
	 * @param $order_id
	 * @return
	 *
	 */
	public static function get_eye4fraud_status( $order_id ) {
		global $wpdb;
		return $wpdb->get_row( $wpdb->prepare( "SELECT * FROM {$wpdb->prefix}eye4fraud_status WHERE order_id = %d", $order_id ) );
	}


	/**
	 * Check the orders which are not sent to eye4fraud
	 */
	public static function get_eye4fraud_status_missed_orders() {
		global $wpdb;
		return $wpdb->get_results(
			$wpdb->prepare( "
                SELECT {$wpdb->prefix}posts.`ID` FROM {$wpdb->prefix}posts 
                WHERE 
                    {$wpdb->prefix}posts.post_date >= DATE_ADD(CURDATE(), INTERVAL -2 DAY) AND 
                    {$wpdb->prefix}posts.`post_type` = 'shop_order' AND 
                    {$wpdb->prefix}posts.`post_status` NOT IN ('wc-cancelled', 'trash', 'wc-failed', 'wc-completed', 'wc-refunded','wc-pending') AND 
                    {$wpdb->prefix}posts.`ID` NOT IN 
                    ( 
                        SELECT {$wpdb->prefix}eye4fraud_status .`order_id` FROM {$wpdb->prefix}eye4fraud_status
                    )
            " ), OBJECT );
	}


	/**
	 * Set Interval and run cron to update the status in Woocommerce Admin
	 *
	 * @param $number_of_days
	 * @return
	 *
	 */
	public static function get_eye4fraud_status_on_cron( $number_of_days ) {
		global $wpdb;
		return $wpdb->get_results(
			$wpdb->prepare( "
                SELECT * FROM {$wpdb->prefix}eye4fraud_status 
                INNER JOIN {$wpdb->prefix}posts ON {$wpdb->prefix}eye4fraud_status.`order_id` = {$wpdb->prefix}posts.`ID` 
                WHERE 
                    {$wpdb->prefix}posts.post_date >= DATE_ADD(CURDATE(), INTERVAL %d DAY) AND 
                    {$wpdb->prefix}eye4fraud_status.status NOT IN ('Approved','Insured','Allowed','Declined','Canceled','Fraud','Error','Unprocessed')
            ", -$number_of_days ), OBJECT );
	}


	/**
	 * Update status in eye4fraud_status table for specific order
	 *
	 * @param $order_id
	 * @param $status
	 * @return
	 *
	 */
	public static function update_status_on_cron( $order_id, $status ) {
		global $wpdb;
		return $wpdb->update(
			$wpdb->prefix . self::TABLE_EYE4FRAUD,
			array( 'status' => $status ),
			array( 'order_id' => $order_id )
		);
	}

}
