<?php

namespace Eye4fraud\Services;

use Eye4fraud\Database\Queries;
use Eye4fraud\Log\Log;
use Eye4fraud\API\Eye4fraud;
use Eye4fraud\Services\SendOrder;
use Eye4fraud\Admin\Admin;
use Eye4fraud\Services\OrderDataProvider;
use Eye4fraud\Base\BaseController;


class Cron extends BaseController {

	public function register() {
		$admin = new Admin();
		$settings = $admin->get_eye4fraud_settings();

		if ( 'yes' != $settings['eye4fraud_disable_cron'] || !$settings['eye4fraud_disable_cron'] ) {
			// If order gets missed due to thankyou page hook not fired
			add_filter( 'cron_schedules', array( $this, 'eye4fraud_order_missed' ) );
			//Cron function which will run on specific time
			add_action( $this->domain . '_cron_orders', array( $this, 'eye4fraud_cron_schedules_order' ) );
			//Schedule event for the missed order cron due to thankyou page hook not fired
			add_action( 'init', array( $this, 'send_orders_eye4fraud' ) );
			// Check order missed -- cron will run in specified number of days
			add_filter( 'cron_schedules', array( $this, 'eye4fraud_add_cron_interval' ) );
			add_action( $this->domain . '_cron_event', array( $this, 'eye4fraud_cron_schedule_order_limit_day' ) );
			add_action( 'woocommerce_update_options_' . $this->domain, array( $this, 'eye4fraud_cron_job_delete' ) );
		}
	}


	/**
	 * Eye4fraud Integration
	 *
	 * @param $schedules
	 * @return mixed
	 *
	 */
	public function eye4fraud_order_missed( $schedules ) {
		$admin = new Admin();
		$settings = $admin->get_eye4fraud_settings();
		$schedules[$this->domain . '_order_missed'] = array(
			'interval' => $settings[$this->domain . '_run_cron_every'],
			'display' => esc_html__( 'Eye4Fraud Order Missed' ),
		);
		return $schedules;
	}


	/**
	 * Eye4fraud Integration
	 *
	 * @param $schedules
	 * @return mixed
	 */
	public function eye4fraud_add_cron_interval( $schedules ) {
		$admin = new Admin();
		$settings = $admin->get_eye4fraud_settings();
		$schedules[$this->domain . '_custom_seconds'] = array(
			'interval' => $settings[$this->domain . '_run_cron_every'],
			'display' => esc_html__( 'Eye4Fraud Custom Seconds' )
		);

		return $schedules;
	}


	/**
	 * Schedule event eye4fraud orders
	 */
	public function send_orders_eye4fraud() {
		if ( !wp_next_scheduled( $this->domain . '_cron_orders' ) ) {
			wp_schedule_event( time(), $this->domain . '_order_missed', $this->domain . '_cron_orders' );
		}

		if ( !wp_next_scheduled( $this->domain . '_cron_event' ) ) {
			wp_schedule_event( time(), $this->domain . '_custom_seconds', $this->domain . '_cron_event' );
		}
	}


	public function eye4fraud_cron_job_delete() {
		wp_clear_scheduled_hook( $this->domain . '_cron_event' );
	}


	/**
	 * Cron function which runs and send data to eye4fraud
	 */
	public function eye4fraud_cron_schedules_order() {
		Log::debug_log_content( 'Cron Start - which runs and send data to eye4fraud...' );
//		global $wpdb;

		$admin = new Admin();
		$send_order = new SendOrder();
		$settings = $admin->get_eye4fraud_settings();
		if ( $settings['eye4fraud_api_enabled'] && 'no' == $settings['eye4fraud_disable_cron'] ) {
			$missedOrders = Queries::get_eye4fraud_status_missed_orders();

			if ( !empty( $missedOrders ) ) {
				Log::debug_log_content( print_r( $missedOrders, true ) );

				foreach ( $missedOrders as $order ) {
					$order_id = $order->ID;
					Log::debug_log_content( 'Cron Start for order id ' . $order_id );
//					$transaction_id = OrderDataProvider::eye4fraud_get_key( $order_id, '_transaction_id' );

//					Log::debug_log_content( 'eye4fraud_cron_schedules_order - missed order - transaction_id = ' . print_r($transaction_id, 1) );

					// TODO: only for debug...
					//---------------------------------------------------------
//					$sql = "SELECT * FROM {$wpdb->prefix}postmeta WHERE `post_id` = $order_id LIMIT 0,100";
//					$postMetaItems = $wpdb->get_results( $wpdb->prepare( $sql ), OBJECT );
//					Log::debug_log_content( $sql );
//					Log::debug_log_content( print_r($postMetaItems, 1) );
					//---------------------------------------------------------

//					if ( !empty( $transaction_id ) ) {
						$send_order->thankyou_page( $order_id );
//					}
				}
			} else {
				Log::debug_log_content( 'Cron runs but NO orders found' );
			}
		}
		Log::debug_log_content( 'Cron End...' );
	}


	/**
	 * Eye4fraud cron scheduling with respect to order limit days in backend settings
	 */
	public function eye4fraud_cron_schedule_order_limit_day() {
		Log::debug_log_content( 'Cron Start - with respect to order limit days in backend settings...' );
		$admin = new Admin();
		$settings = $admin->get_eye4fraud_settings();
		$eye4fraud_object = new Eye4fraud(
			$settings['eye4fraud_api_login'],
			$settings['eye4fraud_api_key'],
			$settings['eye4fraud_api_url']
		);
		$limitDayNum = $settings['eye4fraud_order_limit_day'];
		Log::debug_log_content( 'limitDayNum = ' . $limitDayNum );

		if ( !empty( $limitDayNum ) ) {
			$orders = Queries::get_eye4fraud_status_on_cron( $limitDayNum );
			Log::debug_log_content( print_r( $orders, true ) );

			if ( !empty( $orders ) ) {
				foreach ( $orders as $order ) {
					$order_id = $order->order_id;
					Log::debug_log_content( 'Cron Start for order id ' . $order_id );

					$orderStatus = $eye4fraud_object->get_eye4fraud_status_api( $order_id );
					if ( $orderStatus['success'] ) {
						$desc = (string) $orderStatus['description'];

						if ( 'yes' == $settings['eye4fraud_api_cancel_orders'] ) {
							if ( 'Canceled' == $desc || 'Declined' == $desc || 'Fraud' == $desc ) {
								$order_cancel = wc_get_order( $order_id );
								$order_cancel->update_status( 'cancelled', 'Order is cancelled as Eye4Fraud has cancelled the order' );
								Log::debug_log_content( 'Order id ' . $order_id . ' canceled.' );
							}
						}

						if ( !empty( $settings['eye4fraud_changestatus_orders2'] ) ) {
							Log::debug_log_content( 'auto-change order status...' );

							if ( 'Approved' == $desc || 'Insured' == $desc || 'Unprocessed' == $desc ) {

								$payment_method = get_post_meta( $order_id, '_payment_method', true );
								Log::debug_log_content( 'payment_method = ' . $payment_method );

								$order_new = wc_get_order( $order_id );
								$orderData = $order_new->get_data();
								if ( 'completed' != $orderData['status'] ) {
									$order_new->update_status( $settings['eye4fraud_changestatus_orders2'] );
									$order_new->add_order_note( 'Eye4fraud Status: ' . $desc . '  Woocommerce -- Order Status changed to ' .
										$settings['eye4fraud_changestatus_orders2'] );
								}
							}
						}

						Queries::update_status_on_cron( $order_id, $desc );
						Log::debug_log_content( 'Order id: ' . $order_id . ' Status Updated: ' . $desc );
					}
				}
			}
		}
		Log::debug_log_content( 'Cron End...' );
	}
}
