<?php

namespace Eye4fraud\Services;

use Eye4fraud\API\Eye4fraud;

use Eye4fraud\Admin\Admin;

use Eye4fraud\Services\OrderDataProvider;

use Eye4fraud\Log\Log;

use Eye4fraud\Database\Queries;

use Eye4fraud\Database\InsertTable;


class SendOrder {
	/**
	 * Register function which will run as a constructor.
	 *
	 */

	public function register() {
		add_action( 'woocommerce_thankyou', array( $this, 'thankyou_page' ) );
	}


	/**
	 * Thankyou page hook
	 *
	 * Flag updated for woocommerce_thankyou() function.
	 *
	 * @param $orderId
	 */
	public function thankyou_page( $orderId ) {
		$admin = new Admin();
		$settings = $admin->get_eye4fraud_settings();
		$order = wc_get_order( $orderId );
		$orderData = $order->get_data();
		// Code of remove duplication orders on checkout refresh
		$order_sent_flag = OrderDataProvider::eye4fraud_get_key( $orderId, '_eye4fraud_order_sent' );
		$order_sent = $order_sent_flag && isset( $order_sent_flag[0] ) && $order_sent_flag[0];

		Log::debug_log_content( '-------- thankyou_page -------- ; order_sent = ' . $order_sent );

//		var_dump($orderId, $settings['eye4fraud_api_enabled'], !$order_sent); die;

		if ( $orderId && $settings['eye4fraud_api_enabled'] && !$order_sent ) {
			// Issue solved in thus condition
			$transaction = OrderDataProvider::eye4fraud_get_key( $orderId, '_transaction_id' );
			$eye4fraud = new Eye4fraud( $settings['eye4fraud_api_login'], $settings['eye4fraud_api_key'], $settings['eye4fraud_api_url'] );
			Log::debug_log_content( 'Order Status: ' . $orderData['status'] . ' ; Transaction: ' . print_r( $transaction, 1 ) . ' ; Settings: ' . print_r( $settings, 1 ) );

			// TODO: for test only !
//			$transaction = array(1);

			if ( 'on-hold' == $orderData['status'] || 'processing' == $orderData['status'] ) {
				$payment_method = get_post_meta( $orderId, '_payment_method', true );
				Log::debug_log_content( 'payment_method = ' . $payment_method );

				$transaction_id = '';
				if ($transaction) {
					$transaction_id	= $transaction[0];
				}

				$e4fValues = $this->send_eye4fraud_array( $orderId, $transaction_id, $payment_method );
				Log::debug_log_content( 'Eye4Fraud Request data for order id ' . $orderId );
				Log::debug_log_content( print_r( $e4fValues, true ) );

				$send_to_eye4fraud = $eye4fraud->send_eye4fraud_api( $e4fValues );
				Log::debug_log_content( 'Eye4Fraud Response against order id ' . $orderId );
				Log::debug_log_content( print_r( $send_to_eye4fraud, true ) );

				if ( $send_to_eye4fraud['success'] ) {
					OrderDataProvider::setEye4fraudOrderSent( $orderId, 1 );

					$insert_data = array(
						'order_id' => $orderId,
						'status' => 'Awaiting response'
					);
					Queries::insert_eye4fraud_status( $insert_data );

					Log::debug_log_content( 'Order sent' );
				} else {
					OrderDataProvider::setEye4fraudOrderSent( $orderId, 0 );
					Log::debug_log_content( 'Order not sent - Error: ' . $send_to_eye4fraud['error'] );
				}
			}
		}
	}


	/**
	 * Create array which will be send to eye4fraud
	 *
	 * @param $orderId
	 * @param $transaction_id
	 * @param $auth_cc_array
	 * @return array
	 */
	public function send_eye4fraud_array( $orderId, $transaction_id, $payment_method ) {
		$admin = new Admin();
		$settings = $admin->get_eye4fraud_settings();
		$eye4fraud_array = array();
		if ( isset( $settings['eye4fraud_api_login'] ) && isset( $settings['eye4fraud_api_key'] ) &&
			isset( $settings['eye4fraud_api_url'] ) && !empty( $settings['eye4fraud_api_login'] ) &&
			!empty( $settings['eye4fraud_api_key'] )
		) {
			$order = wc_get_order( $orderId );
			$order_products = $order->get_items();
			$count = 0;
			$product_array = array();

			$isLocalPickup = false;
			if (WC()->session && WC()->session->get( 'chosen_shipping_methods' )) {
				$chosen_shipping_method_id = WC()->session->get( 'chosen_shipping_methods' )[0];
				$isLocalPickup = strpos( $chosen_shipping_method_id, 'local_pickup' ) !== false;
			}

			foreach ( $order_products as $key => $product ) {
				$product_description = get_post( $product['product_id'] )->post_content;
				$_product = wc_get_product( $product['product_id'] );
				$count++;
				$product_array[$count] = array(
					'ProductName' => $product['name'],
					'ProductDescription' => $product_description,
					'ProductSellingPrice' => $_product->get_price(),
					'ProductQty' => $product['qty'],
				);
			}

			$eye4fraud_array = array(
				'ApiLogin' => $settings['eye4fraud_api_login'],
				'ApiKey' => $settings['eye4fraud_api_key'],
				'TransactionId' => $transaction_id,
				'OrderDate' => $order->get_date_created()->format( 'Y-m-d H:i:s' ),
				'OrderNumber' => $orderId,
				'ShippingMethod' => $isLocalPickup ? 'Pickup' : '',
				'BillingFirstName' => $order->get_billing_first_name(),
				'BillingMiddleName' => '',
				'BillingLastName' => $order->get_billing_last_name(),
				'BillingCompany' => $order->get_billing_company(),
				'BillingAddress1' => $order->get_billing_address_1(),
				'BillingAddress2' => $order->get_billing_address_2(),
				'BillingCity' => $order->get_billing_city(),
				'BillingState' => $order->get_billing_state(),
				'BillingZip' => $order->get_billing_postcode(),
				'BillingCountry' => $order->get_billing_country(),
				'BillingEveningPhone' => $order->get_billing_phone(),
				'BillingEmail' => $order->get_billing_email(),
				'IPAddress' => $order->get_customer_ip_address(),
				'ShippingFirstName' => $order->get_shipping_first_name(),
				'ShippingMiddleName' => 'M',
				'ShippingLastName' => $order->get_shipping_last_name(),
				'ShippingCompany' => $order->get_shipping_company(),
				'ShippingAddress1' => $order->get_shipping_address_1(),
				'ShippingAddress2' => $order->get_shipping_address_2(),
				'ShippingCity' => $order->get_shipping_city(),
				'ShippingState' => $order->get_shipping_state(),
				'ShippingZip' => $order->get_shipping_postcode(),
				'ShippingCountry' => $order->get_shipping_country(),
				'ShippingEveningPhone' => $order->get_billing_phone(),
				'ShippingEmail' => $order->get_billing_email(),
				'ShippingCost' => $order->get_total_shipping(),
				'GrandTotal' => $order->get_total(),
				'LineItems' => $product_array,
				'CustomerComments' => $payment_method
			);
		}

		return $eye4fraud_array;
	}

}
